<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddLivraison extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("livraison_statut", ['id' => false, 'primary_key' => ["livraison_statut_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_statut_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_statut_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_statut_id'])
            ->create();

        $this
            ->table("livraison", ['id' => false, 'primary_key' => ["livraison_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_id'])
            ->addColumn('livraison_code', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_rang'])
            ->addColumn('livraison_suivi', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_code'])
            ->addColumn('livraison_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_suivi', 'signed' => false])
            ->addColumn('livraison_delai_min', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_statut_id'])
            ->addColumn('livraison_delai_max', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_delai_min'])
            ->addColumn('livraison_prix_min', 'decimal', ['null' => false, 'precision' => 15, 'scale' => 2, 'after' => 'livraison_delai_max'])
            ->addColumn('livraison_prix_max', 'decimal', ['null' => false, 'precision' => 15, 'scale' => 2, 'after' => 'livraison_prix_min'])
            ->addColumn('livraison_icon', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_prix_max'])
            ->addColumn('livraison_type_id', 'integer', ['null' => false, 'default' => '2', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_icon'])
            ->addColumn('livraison_class', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_type_id'])
            ->addColumn('livraison_icon_map', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_class'])
            ->addForeignKey('livraison_statut_id', 'livraison_statut', 'livraison_statut_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addIndex(['livraison_statut_id'], ['name' => "livraison_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("livraison_boutique", ['id' => false, 'primary_key' => ["livraison_boutique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_boutique_id', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_id', 'signed' => false])
            ->addColumn('livraison_boutique_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id'])
            ->addForeignKey('livraison_id', 'livraison', 'livraison_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['livraison_id', 'boutique_id'], ['name' => "livraison_id_2", 'unique' => true])
            ->addIndex(['livraison_id'], ['name' => "livraison_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->addIndex(['livraison_boutique_statut_id'], ['name' => "livraison_boutique_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("livraison_gratuit", ['id' => false, 'primary_key' => ["livraison_gratuit_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_gratuit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_gratuit_id', 'signed' => false])
            ->addColumn('livraison_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id', 'signed' => false])
            ->addColumn('zone_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_id', 'signed' => false])
            ->addColumn('livraison_gratuit_prix', 'decimal', ['null' => false, 'default' => '0.0000', 'precision' => 15, 'scale' => 4, 'after' => 'zone_id'])
            ->addColumn('taxe_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_gratuit_prix', 'signed' => false])
            ->addForeignKey('livraison_id', 'livraison', 'livraison_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('zone_id', 'zone', 'zone_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('taxe_id', 'taxe', 'taxe_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['livraison_id'], ['name' => "livraison_id", 'unique' => false])
            ->addIndex(['zone_id'], ['name' => "zone_id", 'unique' => false])
            ->addIndex(['taxe_id'], ['name' => "taxe_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->create();

        $this
            ->table("livraison_nom", ['id' => false, 'primary_key' => ["livraison_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_nom_id', 'signed' => false])
            ->addColumn('langue_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_id', 'signed' => false])
            ->addColumn('livraison_nom_nom', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'langue_id'])
            ->addColumn('livraison_nom_desc', 'text', ['null' => false, 'limit' => 65535, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_nom_nom'])
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('livraison_id', 'livraison', 'livraison_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id', 'livraison_id'], ['name' => "langue_id_2", 'unique' => true])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['livraison_id'], ['name' => "livraison_id", 'unique' => false])
            ->create();

        $this
            ->table("livraison_type", ['id' => false, 'primary_key' => ["livraison_type_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_type_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_type_rang', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_type_id'])
            ->create();

        $this
            ->table("livraison_type_nom", ['id' => false, 'primary_key' => ["livraison_type_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_type_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('livraison_type_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_type_nom_id', 'signed' => false])
            ->addColumn('livraison_type_nom_nom', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'livraison_type_id'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_type_nom_nom', 'signed' => false])
            ->addForeignKey('livraison_type_id', 'livraison_type', 'livraison_type_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id', 'livraison_type_id'], ['name' => "langue_id_2", 'unique' => true])
            ->addIndex(['livraison_type_id'], ['name' => "livraison_type_id", 'unique' => false])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->create();

        $this
            ->table("livraison_zone", ['id' => false, 'primary_key' => ["livraison_zone_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('livraison_zone_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_zone_id', 'signed' => false])
            ->addColumn('livraison_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id', 'signed' => false])
            ->addColumn('zone_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_id', 'signed' => false])
            ->addColumn('livraison_zone_prix', 'decimal', ['null' => false, 'default' => '0.0000', 'precision' => 15, 'scale' => 4, 'after' => 'zone_id'])
            ->addColumn('taxe_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'livraison_zone_prix', 'signed' => false])
            ->addColumn('livraison_zone_prix_min', 'decimal', ['null' => false, 'default' => '0.0000', 'precision' => 15, 'scale' => 4, 'after' => 'taxe_id'])
            ->addColumn('livraison_zone_prix_max', 'decimal', ['null' => false, 'default' => '0.0000', 'precision' => 15, 'scale' => 4, 'after' => 'livraison_zone_prix_min'])
            ->addForeignKey('zone_id', 'zone', 'zone_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('taxe_id', 'taxe', 'taxe_id', array(
                'delete' => 'RESTRICT',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('livraison_id', 'livraison', 'livraison_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['livraison_id'], ['name' => "livraison_id", 'unique' => false])
            ->addIndex(['zone_id'], ['name' => "zone_id", 'unique' => false])
            ->addIndex(['taxe_id'], ['name' => "taxe_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->create();
    }
}
