<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddParrainage extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("parrainage", ['id' => false, 'primary_key' => ["parrainage_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('parrainage_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('parrainage_gain', 'decimal', ['null' => false, 'default' => '0.00', 'precision' => 15, 'scale' => 2, 'after' => 'parrainage_id'])
            ->addColumn('parrainage_gain_filleul', 'decimal', ['null' => false, 'default' => '0.00', 'precision' => 15, 'scale' => 2, 'after' => 'parrainage_gain'])
            ->addColumn('parrainage_montant', 'decimal', ['null' => false, 'default' => '0.0000', 'precision' => 15, 'scale' => 4, 'after' => 'parrainage_gain_filleul'])
            ->addColumn('parrainage_nbjour', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'parrainage_montant'])
            ->create();

        $this
            ->table("parrainage_boutique", ['id' => false, 'primary_key' => ["parrainage_boutique_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('parrainage_boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('parrainage_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'parrainage_boutique_id', 'signed' => false])
            ->addColumn('boutique_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'parrainage_id', 'signed' => false])
            ->addColumn('parrainage_boutique_statut_id', 'integer', ['null' => false, 'default' => '1', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'boutique_id'])
            ->addForeignKey('parrainage_id', 'parrainage', 'parrainage_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('boutique_id', 'boutique', 'boutique_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['parrainage_id', 'boutique_id'], ['name' => "parrainage_id_2", 'unique' => true])
            ->addIndex(['parrainage_id'], ['name' => "parrainage_id", 'unique' => false])
            ->addIndex(['boutique_id'], ['name' => "boutique_id", 'unique' => false])
            ->addIndex(['parrainage_boutique_statut_id'], ['name' => "parrainage_boutique_statut_id", 'unique' => false])
            ->create();

        $this
            ->table("parrainage_nom", ['id' => false, 'primary_key' => ["parrainage_nom_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('parrainage_nom_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('parrainage_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'parrainage_nom_id', 'signed' => false])
            ->addColumn('parrainage_nom_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'parrainage_id'])
            ->addColumn('langue_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'parrainage_nom_nom', 'signed' => false])
            ->addForeignKey('parrainage_id', 'parrainage', 'parrainage_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('langue_id', 'langue', 'langue_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['langue_id', 'parrainage_id'], ['name' => "langue_id_2", 'unique' => true])
            ->addIndex(['langue_id'], ['name' => "langue_id", 'unique' => false])
            ->addIndex(['parrainage_id'], ['name' => "parrainage_id", 'unique' => false])
            ->create();
    }
}
