<?php

namespace Module;

use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Router;

/**
 * Class ModuleLoader
 * @package Module
 */
class ModuleLoader {

    /**
     * @var Module[]
     */
    protected $modules;

    /**
     * @var Router
     */
    protected $router;

    /**
     * @var EventDispatcherInterface
     */
    protected $eventDispatcher;

    /**
     * ModuleLoader constructor.
     * @param \Router $router
     * @param EventDispatcherInterface $eventDispatcher
     */
    public function __construct(Router $router, EventDispatcherInterface $eventDispatcher)
    {
        $this->eventDispatcher = $eventDispatcher;
        $this->router = $router;
        $this->modules = array();
    }

    /**
     * @param Module $module
     * @return $this
     */
    public function addModule(Module $module)
    {
        $this->modules[] = $module;
        return $this;
    }

    /**
     * @param $modules
     * @return $this
     */
    public function setModule($modules)
    {
        $this->modules = array_merge($this->modules, $modules);
        return $this;
    }

    /**
     *
     */
    public function load()
    {
        if (!empty($this->modules)) {
            foreach ($this->modules as $className => $environnements) {
                if (!is_array($environnements)) {
                    throw new \DediException('the list of environnements must be an array');
                }

                if (in_array(getenv('APP_ENV'), $environnements) || in_array('all', $environnements)) {
                    $this->create($className)->register();
                }
            }
        }
    }

    /**
     * @param $className
     * @return mixed
     * @throws \DediException
     */
    protected function create($className)
    {
        if (class_exists($className) == false) {
            throw new \DediException(sprintf('the class %s doesnt exist', $className));
        }

        return new $className($this->router, $this->eventDispatcher);
    }
}
